# load packages
# remove.packages("haven")
# install.packages("haven")
require(FactoMineR)
require(ggplot2)
source("Functions.R")
library(haven)


setwd("C:\Users\claudiu\RStudioProjects\MCA_case_study")
getwd()

source("Functions.R")

FES_YOUTH_STUDY_ROMANIA <- read_sav("FES YOUTH STUDY ROMANIA.sav", user_na = T)
# FES_YOUTH_STUDY_ROMANIA <- read.table("FES YOUTH STUDY ROMANIA-data.csv", 
#                                      header = T, sep = ";")
# View(FES_YOUTH_STUDY_ROMANIA)


emi <- data.frame(FES_YOUTH_STUDY_ROMANIA[73], 
                  FES_YOUTH_STUDY_ROMANIA[78:78],
                 FES_YOUTH_STUDY_ROMANIA[81:81], 
                 FES_YOUTH_STUDY_ROMANIA[112])
col_headings <- c('Religion', 'Church', 'Holidays', 'Emigration')
names(emi) <- col_headings

View(emi)


emi[,1] <- correctReligionRomania(emi[,1])
emi[,2] <- correctChurch(emi[,2])
emi[,3] <- correctPray(emi[,3])
# emi[,4] <- correctPray(emi[,4])
# for (j in 4:5) {
#   emi[,j] <- correctReligiousPractice(emi[,j])
# }
emi[,4] <- correctEmigration(emi[,4])

View(emi)
write.csv(emi, "MCA_Romania.csv")

nv <- ncol(emi)
no <- nrow(emi)
nv; no

# number of categories per variable
# cats <- apply(emi, 2, FUN = function(x) nlevels(as.factor(x)))
cats = apply(emi, 2, function(x) nlevels(as.factor(x)))
cats


# apply MCA
mca1 = MCA(emi, ncp=4, na.method="NA", graph=TRUE)
mca1

# table of eigenvalues
mca1$eig

# eigencalues
mca1$var


# data frame with variable coordinates
# mca1_vars_df = data.frame(mca1$var$coord, Variable = rep(names(cats), cats))
mca1_vars_df = data.frame(rbind(mca1$var$coord,
                                mca1$quali.sup$coord), 
                          Variable = rep(names(cats), cats))
mca1_vars_df
write.csv(mca1_obs_df, "mca1_var_Romania.csv")

# data frame with observation coordinates
mca1_obs_df = data.frame(mca1$ind$coord)
mca1_obs_df
write.csv(mca1_obs_df, "mca1_obs_Romania.csv")

# plot of variable categories
ggplot(data=mca1_vars_df, 
       aes(x = Dim.1, y = Dim.2, label = rownames(mca1_vars_df))) +
  geom_hline(yintercept = 0, colour = "gray70") +
  geom_vline(xintercept = 0, colour = "gray70") +
  geom_text(aes(colour=Variable)) +
  ggtitle("Romania - MCA plot of variables in the space of Dim. 1 and Dim. 2")

# MCA plot of observations and categories
ggplot(data = mca1_obs_df, aes(x = Dim.1, y = Dim.2)) +
  geom_hline(yintercept = 0, colour = "gray70") +
  geom_vline(xintercept = 0, colour = "gray70") +
  geom_point(colour = "gray50", alpha = 0.7) +
  geom_density2d(colour = "gray80") +
  geom_text(data = mca1_vars_df, 
            aes(x = Dim.1, y = Dim.2, 
                label = rownames(mca1_vars_df), colour = Variable)) +
  ggtitle("Romania - MCA plot of variables in the space of Dim. 1 and Dim. 2") +
  scale_colour_discrete(name = "Variable")


